@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 3.5.3.  */
+/* A Bison parser, made by GNU Bison 3.6.3.  */
 
 /* Bison interface for Yacc-like parsers in C
 
@@ -31,8 +31,9 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-/* Undocumented macros, especially those whose name start with YY_,
-   are private implementation details.  Do not rely on them.  */
+/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
+   especially those whose name start with YY_ or yy_.  They are
+   private implementation details that can be changed or removed.  */
 
 #ifndef YY_GRAPHYY_Y_TAB_H_INCLUDED
 # define YY_GRAPHYY_Y_TAB_H_INCLUDED
@@ -44,24 +45,32 @@
 extern int graphyydebug;
 #endif
 
-/* Token type.  */
+/* Token kinds.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
   enum yytokentype
   {
-    VOLUME_BEGIN = 258,
-    VOLUME_END = 259,
-    OPTION = 260,
-    NEWLINE = 261,
-    SUBVOLUME = 262,
-    ID = 263,
-    WHITESPACE = 264,
-    COMMENT = 265,
-    TYPE = 266,
-    STRING_TOK = 267
+    YYEMPTY = -2,
+    YYEOF = 0,                     /* "end of file"  */
+    YYerror = 256,                 /* error  */
+    YYUNDEF = 257,                 /* "invalid token"  */
+    VOLUME_BEGIN = 258,            /* VOLUME_BEGIN  */
+    VOLUME_END = 259,              /* VOLUME_END  */
+    OPTION = 260,                  /* OPTION  */
+    NEWLINE = 261,                 /* NEWLINE  */
+    SUBVOLUME = 262,               /* SUBVOLUME  */
+    ID = 263,                      /* ID  */
+    WHITESPACE = 264,              /* WHITESPACE  */
+    COMMENT = 265,                 /* COMMENT  */
+    TYPE = 266,                    /* TYPE  */
+    STRING_TOK = 267               /* STRING_TOK  */
   };
+  typedef enum yytokentype yytoken_kind_t;
 #endif
-/* Tokens.  */
+/* Token kinds.  */
+#define YYEOF 0
+#define YYerror 256
+#define YYUNDEF 257
 #define VOLUME_BEGIN 258
 #define VOLUME_END 259
 #define OPTION 260
